Harmony API (0.9.0)

Download OpenAPI specification:Download

Intermediary Service for Pathfinder Applications

Following this API, you can register your application endpoints and product footprint IDs with Pathfinder Harmony to provide a way for other companies to find and access the product footprints associated with your products. Product footprints are still sent and received via peer-to-peer communication between applications.

Register Public Key

The application generates a key pair and registers only the public key. Existing public keys, if any, will be overwritten. Private keys are not stored, so please store them appropriately on the application side.

Authorizations:
BearerToken
Request Body schema: application/json
publicKey
required
string

Responses

Request samples

Content type
application/json
{
  • "publicKey": "string"
}

Delete Public Key

Authorizations:
BearerToken

Responses

Register Data Source

Authorizations:
BearerToken
Request Body schema: application/json
userName
required
string <byte>

It is encrypted with the recipient's public key and Base64 encoded.

password
required
string <byte>

Passwords must be at least 8 and no more than 32 characters long and contain all uppercase and lowercase letters, numbers, and symbols. It is encrypted with the recipient's public key and Base64 encoded.

required
Array of objects (PathfinderEndpoint)

Responses

Request samples

Content type
application/json
{
  • "userName": "c2FtcGxlQGV4YW1wbGUuY29t",
  • "password": "KFNhbSlwbDM=",
  • "endpoints": [
    ]
}

Delete Data Source

Authorizations:
BearerToken

Responses

Notify Event

Set one of the following values to the type property depending on the content of the notification.

org.wbcsd.pathfinder.Company.Updated.v1
Used when company information has changed.
org.wbcsd.pathfinder.Product.Updated.v1
Used when product information has changed.
org.wbcsd.pathfinder.ProductFootprint.Updated.v1
Used when a product footprint is generated or updated.
org.wbcsd.pathfinder.Contract.Request.v1
Used by one company to request Pathfinder endpoints and credentials from another company.

Authorizations:
BearerToken
Request Body schema: application/cloudevents+json
One of
id
required
string

Event identifier. Must be able to uniquely identify the event by source and id.

specversion
required
string

CloudEvents version.

source
required
string^\/\/[-a-zA-Z0-9@:%._\+~#=]+\/[-a-zA-Z0-9()@:...

The domain and endpoint of the application from which the event originates.

time
required
string <date-time>

The time the event occurred.

type
required
string
Value: "org.wbcsd.pathfinder.Company.Updated.v1"
required
object

Responses

Request samples

Content type
application/cloudevents+json
Example
{
  • "id": "string",
  • "specversion": "1.0",
  • "source": "//example.com/2/events",
  • "time": "2024-08-01T10:50:30Z",
  • "type": "org.wbcsd.pathfinder.Company.Updated.v1",
  • "data": {
    }
}