Harmony Client API (0.9.0)

Download OpenAPI specification:Download

API to communicate with Pathfinder Harmony

By implementing this API, you can receive requests from Pathfinder Harmony and receive responses from other applications. You can also follow this API to send requests to Pathfinder Harmony and responses to other applications.

Notify Event

Notifies you of events that occur in Pathfinder Harmony or in an application. The request format is CloudEvents, which strictly follows the Action Events in the Pathfinder Tech Spec.

Authorizations:
BearerToken
Request Body schema: application/cloudevents+json
One of
id
required
string

Event identifier. Must be able to uniquely identify the event by source and id.

specversion
required
string

CloudEvents version.

source
required
string^\/\/[-a-zA-Z0-9@:%._\+~#=]+\/[-a-zA-Z0-9()@:...

The domain and endpoint of the application from which the event originates.

time
required
string <date-time>

The time the event occurred.

type
required
string
Value: "org.wbcsd.pathfinder.Contract.Request.v1"
required
object

Responses

Request samples

Content type
application/cloudevents+json
Example
{
  • "id": "string",
  • "specversion": "string",
  • "source": "//example.com/2/events",
  • "time": "2024-08-01T10:50:30Z",
  • "type": "org.wbcsd.pathfinder.Contract.Request.v1",
  • "data": {
    }
}